nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Cpha

Enum Cpha 

#[repr(u8)]
pub enum Cpha { CHANGE = 0, CAPTURE = 1, }

Variants



CHANGE = 0

Change. The SPI captures serial data on the first clock transition of the transfer (when the clock changes away from the rest state). Data is changed on the following edge.



CAPTURE = 1

Capture. The SPI changes serial data on the first clock transition of the transfer (when the clock changes away from the rest state). Data is captured on the following edge.

Implementations

Source

impl Cpha

pub const fn from_bits(val: u8) -> Cpha

pub const fn to_bits(self) -> u8