nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Txignore

Enum Txignore 

#[repr(u8)]
pub enum Txignore { WRITETXDATA = 0, IGNORETXDATA = 1, }

Variants



WRITETXDATA = 0

Write transmit data. Transmit data must be written for each data exchange between master and slave. In slave mode, an underrun error occurs if transmit data is not provided before needed in a data frame.



IGNORETXDATA = 1

Ignore transmit data. Data can be received without transmitting data (after FIFOWR has been initialized to set TXIGNORE). No transmitter flags are generated. When configured with TXIGNORE = 1, the slave sets the data to always 0.

Implementations

Source

impl Txignore

pub const fn from_bits(val: u8) -> Txignore

pub const fn to_bits(self) -> u8